# Telealert

[![PyPI version](https://img.shields.io/pypi/v/telealert.svg)](https://pypi.org/project/telealert/)
[![License: MIT](https://img.shields.io/badge/License-MIT-green.svg)](LICENSE)

**Telealert** — a simple asynchronous library for sending notifications to Telegram via a bot.
It makes it easy to integrate your Python project with Telegram. You just need to give it a bot token and a chat ID, then it will send any message you want to that chat.


---

## 🚀 Installation

```bash
pip install telealert